releaseNotes = new ReleaseNotesTool(currentDate: currentDate.clearTime())

/**
 * Velocity tool to search for project versions for release notes.
 */
class ReleaseNotesTool {
	def currentDate

	/**
	 * Returns the first fix version of the issue, or <code>null</code> if not set.
	 */
	def findFixVersion(def issue) {
		issue.fixVersions.find()
	}

	/**
	 * Returns the released version with the most recent release date, or <code>null</code> if not found.
	 */
	def findLastReleasedVersion(def project) {
		def result = project.versions.findAll {
			it.released && (it.releaseDate.compareTo(currentDate) <= 0)
		}.sort(releaseDateComparator)
		result ? result.last() : null
	}

	/**
	 * Returns the unreleased version with the closest release date, or <code>null</code> if not found.
	 */
	def findNextUnreleasedVersion(def project) {
		def result = project.versions.findAll {
			!it.released && it.releaseDate && (it.releaseDate.compareTo(currentDate) >= 0)
		}.sort(releaseDateComparator)
		result ? result.first() : null
	}

	private def releaseDateComparator = { a, b -> a.releaseDate <=> b.releaseDate }
}